@@ -1,6 +1,10 @@
 from abc import ABC, abstractmethod
 
 
+class InvalidInitialContent(Exception):
+    pass
+
+
 class PID(ABC):
 
     @abstractmethod
@@ -15,14 +19,6 @@ class PID(ABC):
     def __ne__(self, x):
         pass
 
-    @abstractmethod
-    def __lt__(self, x):
-        pass
-
-    @abstractmethod
-    def __gt__(self, x):
-        pass
-
     @abstractmethod
     def __neg__(self):
         pass
@@ -67,3 +63,21 @@ class PID(ABC):
         if not (self // x).isUnit():
             return False
         return True
+
+    @abstractmethod
+    def extended_gcd(a, b):
+        """
+        This should return a tuple (g, x, y) such where
+        - g is the gcd of self and x
+        - g = a * y + b * x
+        Such a tuple will always exist since all principle ideal
+        domains are bezout domains.
+
+        Note that if your principle ideal domain is additionally a euclidean
+        domain, the extended euclidean algorithm can be used to find the
+        extended gcd.  Rather than implmenenting the extended euclidean
+        algorithm yourself, you should instead have your PID inherit from
+        smithnormalform.ed.ED instead, which will cause extended_gcd to be
+        implemented for you.
+        """
+        pass
